﻿using OASystem.Domain;

using OASystem.Domain.ViewModels.System;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace OASystem.Infrastructure.Repositories.System
{
    public class UsersRepository : BaseRepository<UserInfoView, JsonView>
    {
        public UsersRepository(SqlSugarClient sqlSugar) : base(sqlSugar)
        {
        }

        /// <summary>
        /// 用户查询列表
        /// </summary>
        /// <param name="_userRep"></param>
        /// <returns></returns>
        public async Task<Result> GetUserList(UsersRepository _userRep)
        {
            Result result = new Result();
            string userSqlWhere = string.Format(@"Select sjp.JobName,sd.DepName,sc.CompanyName,su.* From Sys_Users su 
                                                  Inner Join Sys_Company sc On su.CompanyId = sc.Id
                                                  Inner Join Sys_Department sd On su.DepId = sd.Id
                                                  Inner Join Sys_JobPost sjp On su.JobPostId = sjp.Id ");
            List<UserInfoView> _userList = await _userRep.GetListBySqlWithNolockAsync(userSqlWhere);
            if (_userList.Count < 1)
            {
                result.Code = -2;
                result.Msg = "暂无员工信息!";

                return result;
            }

            List<dynamic> reultUserList = new List<dynamic>();
            foreach (UserInfoView user in _userList)
            {
                var data = new
                {
                    Number = user.Number,
                    UserId = user.Id,
                    CnName = user.CnName,
                    CompanyId = user.CompanyId,
                    CompanyName = user.CompanyName,
                    DepId = user.DepId,
                    DepName = user.DepName,
                    JobPostId = user.JobPostId,
                    JobName = user.JobName,
                    Ext = user.Ext,
                    Phone = user.Phone,
                    UrgentPhone = user.UrgentPhone,
                    Email = user.Email
                };
                reultUserList.Add(data);
            }

            result.Code = 0;
            result.Msg = "成功!";
            result.Data = reultUserList;
            return result;

        }
    }
}
